Contributing to MNE-NIRS
========================

MNE-NIRS is maintained by a community of scientists and research labs. The project accepts contributions in the form of bug reports, fixes, feature additions, and documentation improvements (including typo corrections). The best way to start contributing is by [opening an issue](https://github.com/mne-tools/mne-nirs/issues/new/choose) on our GitHub page to discuss ideas for changes or enhancements, or to tell us about behavior that you think might be a bug. For *general troubleshooting* or *usage questions*, please consider posting your questions on our [MNE Forum](https://mne.discourse.group).

This project follows the same community guidelines as MNE-Python.

Users and contributors to MNE-NIRS are expected to follow our [code of conduct](https://github.com/mne-tools/.github/blob/main/CODE_OF_CONDUCT.md).

The [contributing guide](https://mne.tools/dev/install/contributing.html) has details on the preferred contribution workflow
and the recommended system configuration for a smooth contribution/development experience.
